<?php

/**
 * NOTICE OF LICENSE.
 *
 * This file is licenced under the Software License Agreement.
 * With the purchase or the installation of the software in your application
 * you accept the licence agreement.
 *
 * You must not modify, adapt or create derivative works of this source code
 *
 * @author    www.mergado.cz
 * @copyright 2016 Mergado technologies, s. r. o.
 * @license   LICENSE.txt
 */

namespace Mergado\Biano;

use Mergado\Tools\Languages;
use Mergado\Tools\Settings;

class BianoStarService {
	const ACTIVE = 'mmp_biano_star_active';
	const SHIPMENT_IN_STOCK = 'mmp_biano_star_shipment_in_stock';
	const SHIPMENT_BACKORDER = 'mmp_biano_star_shipment_backorder';
	const SHIPMENT_OUT_OF_STOCK = 'mmp_biano_star_shipment_out_of_stock';

    const OPT_OUT = 'mmp_biano_start_opt_out_text_';

    const DEFAULT_OPT = 'Do not send a satisfaction questionnaire within the Biano Star program.';

	private $active;
	private $shipmentInStock;
	private $shipmentBackorder;
	private $shipmentOutOfStock;

	/******************************************************************************************************************
	 * IS
	 ******************************************************************************************************************/

	/**
     * Biano star is dependant on Biano
     * Check of Biano activation is omitted because this function is used only inside Biano call.
     *
	 * @return bool
	 */
	public function isActive($lang) {
		$active = $this->getActive();
        $bianoService = new BianoService();

		if ( $active === '1' && $bianoService->isActive($lang)) {
			return true;
		} else {
			return false;
		}
	}

	/*******************************************************************************************************************
	 * GET
	 *******************************************************************************************************************/

	/**
	 * @return false|mixed|void
	 */
	public function getActive() {
		if ( ! is_null( $this->active ) ) {
			return $this->active;
		}

		$this->active = get_option( self::ACTIVE, 0 );

		return $this->active;
	}

    /**
     * @return false|mixed|void
     */
    public function getShipmentInStock() {
        if ( ! is_null( $this->shipmentInStock ) ) {
            return $this->shipmentInStock;
        }

        $this->shipmentInStock = (int) get_option( self::SHIPMENT_IN_STOCK, 0 );

        return $this->shipmentInStock;
    }

    /**
     * @return false|mixed|void
     */
    public function getShipmentBackorder() {
        if ( ! is_null( $this->shipmentBackorder ) ) {
            return $this->shipmentBackorder;
        }

        $this->shipmentBackorder = (int) get_option( self::SHIPMENT_BACKORDER, 0 );

        return $this->shipmentBackorder;
    }

    /**
     * @return false|mixed|void
     */
    public function getShipmentOutOfStock() {
        if ( ! is_null( $this->shipmentOutOfStock ) ) {
            return $this->shipmentOutOfStock;
        }

        $this->shipmentOutOfStock = (int) get_option( self::SHIPMENT_OUT_OF_STOCK, 0 );

        return $this->shipmentOutOfStock;
    }

    /**
     * @param $lang
     * @return false|string|null
     */
    public function getOptOut($lang)
    {
        return get_option(self::OPT_OUT . $lang, '');
    }

	/*******************************************************************************************************************
	 * SAVE FIELDS
	 ******************************************************************************************************************/

	/**
	 * @param $post
	 */
	public static function saveFields( $post ) {
		$inputs     = [];
		$checkboxes = [];

        foreach(get_available_languages() as $lang) {
            $inputs[] = self::OPT_OUT . $lang;
        }

        $inputs[] = self::OPT_OUT . 'en_US';
        $inputs[] = self::SHIPMENT_IN_STOCK;
        $inputs[] = self::SHIPMENT_BACKORDER;
        $inputs[] = self::SHIPMENT_OUT_OF_STOCK;

		$checkboxes[] = self::ACTIVE;

		Settings::saveOptions( $post,
			$checkboxes
			,
			$inputs
		);
	}
}
